@@ -36,12 +36,13 @@
 
 const char *gweather_gettext (const char *str) G_GNUC_FORMAT (1);
 const char *gweather_dpgettext (const char *context, const char *str) G_GNUC_FORMAT (2);
+void        _gweather_gettext_init (void);
 #define _(str) (gweather_gettext (str))
 #define C_(context, str) (gweather_dpgettext (context, str))
 #define N_(str) (str)
 
 struct _GWeatherLocation {
-    char *name, *sort_name;
+    char *name, *msgctxt, *sort_name;
     GWeatherLocation *parent, **children;
     GWeatherLocationLevel level;
     char *country_code, *tz_hint;
@@ -90,7 +91,6 @@ typedef gdouble GWeatherVisibility;
 typedef time_t GWeatherUpdate;
 
 struct _GWeatherInfoPrivate {
-    GWeatherForecastType forecast_type;
     GWeatherProvider providers;
 
     GSettings *settings;
@@ -103,8 +103,15 @@ struct _GWeatherInfoPrivate {
     gboolean polarNight;
     gboolean moonValid;
     gboolean tempMinMaxValid;
+
+    /* TRUE if we don't need to calc humidity from
+       temperature and dew point (and conversely, we
+       need to calculate the dew point from temperature
+       and humidity)
+    */
+    gboolean hasHumidity;
+
     WeatherLocation location;
-    GWeatherLocation *world;
     GWeatherLocation *glocation;
     GWeatherUpdate update;
     GWeatherUpdate current_time;
@@ -114,6 +121,7 @@ struct _GWeatherInfoPrivate {
     GWeatherTemperature temp_min;
     GWeatherTemperature temp_max;
     GWeatherTemperature dew;
+    GWeatherHumidity humidity;
     GWeatherWindDirection wind;
     GWeatherWindSpeed windspeed;
     GWeatherPressure pressure;
@@ -122,7 +130,6 @@ struct _GWeatherInfoPrivate {
     GWeatherUpdate sunset;
     GWeatherMoonPhase moonphase;
     GWeatherMoonLatitude moonlatitude;
-    gchar *forecast;
     GSList *forecast_list; /* list of GWeatherInfo* for the forecast, NULL if not available */
     gchar *forecast_attribution;
     gchar *radar_buffer;
@@ -179,11 +186,10 @@ struct _GWeatherInfoPrivate {
 
 void		metar_start_open	(GWeatherInfo *info);
 gboolean	iwin_start_open		(GWeatherInfo *info);
-void		metoffice_start_open	(GWeatherInfo *info);
-void		bom_start_open		(GWeatherInfo *info);
 void		wx_start_open		(GWeatherInfo *info);
 gboolean        yahoo_start_open        (GWeatherInfo *info);
 gboolean        yrno_start_open         (GWeatherInfo *info);
+gboolean        owm_start_open          (GWeatherInfo *info);
 
 gboolean	metar_parse		(gchar *metar,
 					 GWeatherInfo *info);
