@@ -64,9 +64,7 @@
 
 enum {
     PROP_0,
-    PROP_WORLD,
     PROP_LOCATION,
-    PROP_TYPE,
     PROP_ENABLED_PROVIDERS,
     PROP_LAST
 };
@@ -80,8 +78,8 @@ static guint gweather_info_signals[SIGNAL_LAST];
 
 G_DEFINE_TYPE (GWeatherInfo, gweather_info, G_TYPE_OBJECT);
 
-static inline void
-gweather_gettext_init (void)
+void
+_gweather_gettext_init (void)
 {
     static gsize gweather_gettext_initialized = FALSE;
 
@@ -90,6 +88,12 @@ gweather_gettext_init (void)
 #ifdef HAVE_BIND_TEXTDOMAIN_CODESET
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
+
+        bindtextdomain ("libgweather-locations", GNOMELOCALEDIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+        bind_textdomain_codeset ("libgweather-locations", "UTF-8");
+#endif
+
         g_once_init_leave (&gweather_gettext_initialized, TRUE);
     }
 }
@@ -97,7 +101,7 @@ gweather_gettext_init (void)
 const char *
 gweather_gettext (const char *str)
 {
-    gweather_gettext_init ();
+    _gweather_gettext_init ();
     return dgettext (GETTEXT_PACKAGE, str);
 }
 
@@ -105,7 +109,7 @@ const char *
 gweather_dpgettext (const char *context,
                     const char *str)
 {
-    gweather_gettext_init ();
+    _gweather_gettext_init ();
     return g_dpgettext2 (GETTEXT_PACKAGE, context, str);
 }
 
@@ -254,7 +258,27 @@ free_forecast_list (GWeatherInfo *info)
     info->priv->forecast_list = NULL;
 }
 
-/* Relative humidity computation - thanks to <Olof.Oberg@modopaper.modogroup.com> */
+/* Relative humidity computation - thanks to <Olof.Oberg@modopaper.modogroup.com>
+   calc_dew is simply the inverse of calc_humidity */
+
+static inline gdouble
+calc_dew (gdouble temp, gdouble humidity)
+{
+    gdouble esat, esurf, tmp;
+
+    if (temp > -500.0 && humidity > -1.0) {
+	temp = TEMP_F_TO_C (temp);
+
+	esat = 6.11 * pow (10.0, (7.5 * temp) / (237.7 + temp));
+	esurf = (humidity / 100) * esat;
+    } else {
+	esurf = -1.0;
+	esat = 1.0;
+    }
+
+    tmp = log10 (esurf / 6.11);
+    return TEMP_C_TO_F (tmp * 237.7 / (tmp + 7.5));
+}
 
 static inline gdouble
 calc_humidity (gdouble temp, gdouble dewp)
@@ -281,6 +305,12 @@ calc_apparent (GWeatherInfo *info)
     gdouble wind = WINDSPEED_KNOTS_TO_MPH (info->priv->windspeed);
     gdouble apparent = -1000.;
     gdouble dew = info->priv->dew;
+    gdouble humidity;
+
+    if (info->priv->hasHumidity)
+	humidity = info->priv->humidity;
+    else
+	humidity = calc_humidity (temp, dew);
 
     /*
      * Wind chill calculations as of 01-Nov-2001
@@ -301,10 +331,11 @@ calc_apparent (GWeatherInfo *info)
      * http://www.srh.noaa.gov/fwd/heatindex/heat5.html
      */
     else if (temp >= 80.0) {
-        if (temp >= -500. && dew >= -500.) {
-	    gdouble humidity = calc_humidity (temp, dew);
-	    gdouble t2 = temp * temp;
-	    gdouble h2 = humidity * humidity;
+        if (temp >= -500. && humidity >= 0) {
+	    gdouble t2, h2;
+
+	    t2 = temp * temp;
+	    h2 = humidity * humidity;
 
 #if 1
 	    /*
@@ -359,9 +390,6 @@ gweather_info_reset (GWeatherInfo *info)
 {
     GWeatherInfoPrivate *priv = info->priv;
 
-    g_free (priv->forecast);
-    priv->forecast = NULL;
-
     g_free (priv->forecast_attribution);
     priv->forecast_attribution = NULL;
 
@@ -383,6 +411,7 @@ gweather_info_reset (GWeatherInfo *info)
     priv->temp_min = -1000.0;
     priv->temp_max = -1000.0;
     priv->dew = -1000.0;
+    priv->humidity = -1.0;
     priv->wind = -1;
     priv->windspeed = -1;
     priv->pressure = -1.0;
@@ -394,7 +423,6 @@ gweather_info_reset (GWeatherInfo *info)
     priv->sunset = 0;
     priv->moonphase = 0;
     priv->moonlatitude = 0;
-    priv->forecast = NULL;
     priv->forecast_list = NULL;
     priv->radar = NULL;
 }
@@ -421,6 +449,7 @@ gweather_info_init (GWeatherInfo *info)
 
     priv = info->priv = G_TYPE_INSTANCE_GET_PRIVATE (info, GWEATHER_TYPE_INFO, GWeatherInfoPrivate);
 
+    priv->providers = GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_IWIN;
     priv->settings = g_settings_new ("org.gnome.GWeather");
 
     g_signal_connect_object (priv->settings, "changed",
@@ -563,7 +592,13 @@ gweather_info_update (GWeatherInfo *info)
 
     /* Try yr.no next */
     if (priv->providers & GWEATHER_PROVIDER_YR_NO)
-	yrno_start_open (info);
+	ok = yrno_start_open (info);
+    if (ok)
+	return;
+
+    /* Try OpenWeatherMap next */
+    if (priv->providers & GWEATHER_PROVIDER_OWM)
+	owm_start_open (info);
 }
 
 void
@@ -592,12 +627,6 @@ gweather_info_finalize (GObject *object)
     if (priv->glocation)
 	gweather_location_unref (priv->glocation);
 
-    if (priv->world)
-	gweather_location_unref (priv->world);
-
-    g_free (priv->forecast);
-    priv->forecast = NULL;
-
     g_free (priv->radar_url);
     priv->radar_url = NULL;
 
@@ -806,13 +835,19 @@ gchar *
 gweather_info_get_dew (GWeatherInfo *info)
 {
     GWeatherInfoPrivate *priv;
+    gdouble dew;
 
     g_return_val_if_fail (GWEATHER_IS_INFO (info), NULL);
     priv = info->priv;
 
     if (!priv->valid)
         return g_strdup("-");
-    if (priv->dew < -500.0)
+
+    if (priv->hasHumidity)
+	dew = calc_dew (priv->temp, priv->humidity);
+    else
+	dew = priv->dew;
+    if (dew < -500.0)
         return g_strdup(C_("dew", "Unknown"));
 
     return temperature_string (priv->dew, g_settings_get_enum (priv->settings, TEMPERATURE_UNIT), FALSE);
@@ -828,7 +863,10 @@ gweather_info_get_humidity (GWeatherInfo *info)
     if (!info->priv->valid)
         return g_strdup("-");
 
-    humidity = calc_humidity (info->priv->temp, info->priv->dew);
+    if (info->priv->hasHumidity)
+	humidity = info->priv->humidity;
+    else
+	humidity = calc_humidity (info->priv->temp, info->priv->dew);
     if (humidity < 0.0)
         return g_strdup(C_("humidity", "Unknown"));
 
@@ -1092,13 +1130,6 @@ gweather_info_get_sunset (GWeatherInfo *info)
     return buf;
 }
 
-gchar *
-gweather_info_get_forecast (GWeatherInfo *info)
-{
-    g_return_val_if_fail (GWEATHER_IS_INFO (info), NULL);
-    return g_strdup (info->priv->forecast);
-}
-
 /**
  * gweather_info_get_forecast_list:
  * @info: a #GWeatherInfo
@@ -1747,13 +1778,20 @@ gweather_info_get_value_temp_max (GWeatherInfo *info, GWeatherTemperatureUnit un
 gboolean
 gweather_info_get_value_dew (GWeatherInfo *info, GWeatherTemperatureUnit unit, gdouble *value)
 {
+    gdouble dew;
+
     g_return_val_if_fail (GWEATHER_IS_INFO (info), FALSE);
     g_return_val_if_fail (value != NULL, FALSE);
 
     if (!info->priv->valid)
 	return FALSE;
 
-    return temperature_value (info->priv->dew, unit, value, info->priv->settings);
+    if (info->priv->hasHumidity)
+	dew = calc_dew (info->priv->temp, info->priv->humidity);
+    else
+	dew = info->priv->dew;
+
+    return temperature_value (dew, unit, value, info->priv->settings);
 }
 
 /**
@@ -1965,16 +2003,12 @@ gweather_info_set_location_internal (GWeatherInfo     *info,
 	gweather_location_unref (priv->glocation);
     _weather_location_free (&priv->location);
 
-    if (!priv->world && location)
-	priv->world = gweather_location_ref_world (location);
-
-    if (!priv->world)
-	priv->world = gweather_location_new_world (TRUE);
-
     priv->glocation = location;
+
     if (priv->glocation) {
 	gweather_location_ref (location);
     } else {
+	GWeatherLocation *world;
 	GVariant *default_loc = g_settings_get_value (priv->settings, DEFAULT_LOCATION);
 	const gchar *station_code;
 
@@ -1983,7 +2017,8 @@ gweather_info_set_location_internal (GWeatherInfo     *info,
 	if (strcmp(name, "") == 0)
 	    name = NULL;
 
-	priv->glocation = gweather_location_find_by_station_code (priv->world, station_code);
+	world = gweather_location_get_world ();
+	priv->glocation = gweather_location_find_by_station_code (world, station_code);
     }
 
     _gweather_location_update_weather_location (priv->glocation,
@@ -2009,6 +2044,8 @@ gweather_info_set_location_internal (GWeatherInfo     *info,
  * @location: (allow-none): a location for which weather is desired
  *
  * Changes @info to report weather for @location.
+ * Note that this will clear any forecast or current conditions from
+ * @info, you must call gweather_info_update() to obtain the new data.
  */
 void
 gweather_info_set_location (GWeatherInfo     *info,
@@ -2017,7 +2054,7 @@ gweather_info_set_location (GWeatherInfo     *info,
     g_return_if_fail (GWEATHER_IS_INFO (info));
 
     gweather_info_set_location_internal (info, location);
-    gweather_info_update (info);
+    gweather_info_reset (info);
 }
 
 GWeatherProvider
@@ -2053,22 +2090,14 @@ gweather_info_set_property (GObject *object,
 			    GParamSpec *pspec)
 {
     GWeatherInfo *self = GWEATHER_INFO (object);
-    GWeatherInfoPrivate *priv = self->priv;
 
     switch (property_id) {
-    case PROP_WORLD:
-	priv->world = g_value_dup_boxed (value);
-	break;
     case PROP_LOCATION:
 	gweather_info_set_location_internal (self, (GWeatherLocation*) g_value_get_boxed (value));
 	break;
-    case PROP_TYPE:
-	priv->forecast_type = g_value_get_enum (value);
-	break;
     case PROP_ENABLED_PROVIDERS:
 	gweather_info_set_enabled_providers (self, g_value_get_flags (value));
 	break;
-
     default:
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     }
@@ -2084,15 +2113,9 @@ gweather_info_get_property (GObject    *object,
     GWeatherInfoPrivate *priv = self->priv;
 
     switch (property_id) {
-    case PROP_WORLD:
-	g_value_set_boxed (value, priv->world);
-	break;
     case PROP_LOCATION:
 	g_value_set_boxed (value, priv->glocation);
 	break;
-    case PROP_TYPE:
-	g_value_set_enum (value, priv->forecast_type);
-	break;
     case PROP_ENABLED_PROVIDERS:
 	g_value_set_flags (value, priv->providers);
 	break;
@@ -2113,13 +2136,6 @@ gweather_info_class_init (GWeatherInfoClass *klass)
     gobject_class->set_property = gweather_info_set_property;
     gobject_class->get_property = gweather_info_get_property;
 
-    pspec = g_param_spec_boxed ("world",
-				"World",
-				"The hierarchy of locations containing the desired location",
-				GWEATHER_TYPE_LOCATION,
-				G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_DEPRECATED);
-    g_object_class_install_property (gobject_class, PROP_WORLD, pspec);
-
     pspec = g_param_spec_boxed ("location",
 				"Location",
 				"The location this info represents",
@@ -2127,14 +2143,6 @@ gweather_info_class_init (GWeatherInfoClass *klass)
 				G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
     g_object_class_install_property (gobject_class, PROP_LOCATION, pspec);
 
-    pspec = g_param_spec_enum ("forecast-type",
-			       "Forecast type",
-			       "The type of forecast desired (list, zone or state)",
-			       GWEATHER_TYPE_FORECAST_TYPE,
-			       GWEATHER_FORECAST_LIST,
-			       G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
-    g_object_class_install_property (gobject_class, PROP_TYPE, pspec);
-
     pspec = g_param_spec_flags ("enabled-providers",
 				"Enabled providers",
 				"A bitmask of enabled weather service providers",
@@ -2163,65 +2171,61 @@ gweather_info_class_init (GWeatherInfoClass *klass)
 
 /**
  * gweather_info_new:
- * @location: (allow-none): the desidered #GWeatherLocation (NULL for default)
- * @forecast_type: the type of forecast requested
+ * @location: (allow-none): the desidered #GWeatherLocation (%NULL for default)
+ * @type: deprecated and ignored
  *
  * Builds a new #GWeatherInfo that will provide weather information about
  * @location.
- * Note that, as compared to g_object_new(), this will call gweather_info_update()
- * on the resulting info, which will not be ready until the #GWeatherInfo::updated
- * signal is emitted.
  *
  * Returns: (transfer full): a new #GWeatherInfo
  */
 GWeatherInfo *
-gweather_info_new (GWeatherLocation    *location,
-		   GWeatherForecastType forecast_type)
+gweather_info_new (GWeatherLocation     *location,
+		   GWeatherForecastType  type)
 {
     GWeatherInfo *self;
 
     if (location != NULL)
-	self = g_object_new (GWEATHER_TYPE_INFO, "location", location, "forecast-type", forecast_type, NULL);
+	self = g_object_new (GWEATHER_TYPE_INFO, "location", location, NULL);
     else
-	self = g_object_new (GWEATHER_TYPE_INFO, "forecast-type", forecast_type, NULL);
+	self = g_object_new (GWEATHER_TYPE_INFO, NULL);
+
     gweather_info_update (self);
-
-    return self;
-}
-
-/**
- * gweather_info_new_for_world:
- * @world: a #GWeatherLocation representing the whole world
- * @location: (allow-none): the desidered #GWeatherLocation (NULL for default)
- * @forecast_type: the type of forecast requested
- *
- * Similar to gweather_info_new(), but also has a @world parameter, that allow controlling
- * the hierarchy of #GWeatherLocation to which @location (or the default one taken from
- * GSettings) belongs.
- *
- * Returns: (transfer full): a new #GWeatherInfo
- *
- * Deprecated: there is only one world-level #GWeatherLocation at any time, so
- *             this is the same as gweather_info_new().
- */
-GWeatherInfo *
-gweather_info_new_for_world (GWeatherLocation    *world,
-			     GWeatherLocation    *location,
-			     GWeatherForecastType forecast_type)
-{
-    GWeatherInfo *self;
-
-    if (location != NULL)
-	self = g_object_new (GWEATHER_TYPE_INFO, "world", world, "location", location, "forecast-type", forecast_type, NULL);
-    else
-	self = g_object_new (GWEATHER_TYPE_INFO, "world", world, "forecast-type", forecast_type, NULL);
-    gweather_info_update (self);
-
     return self;
 }
 
 GWeatherInfo *
 _gweather_info_new_clone (GWeatherInfo *other)
 {
-    return g_object_new (GWEATHER_TYPE_INFO, "location", other->priv->glocation, "forecast-type", other->priv->forecast_type, NULL);
+    return g_object_new (GWEATHER_TYPE_INFO, "location", other->priv->glocation, NULL);
+}
+
+/* deprecated */
+char *
+gweather_info_get_forecast (GWeatherInfo *info)
+{
+    GString *buffer;
+    GSList *iter;
+
+    buffer = g_string_new ("");
+
+    for (iter = info->priv->forecast_list; iter; iter = iter->next) {
+	char *date, *summary, *temp;
+
+	date = gweather_info_get_update (iter->data);
+	summary = gweather_info_get_conditions (iter->data);
+	if (g_str_equal (summary, "-")) {
+	    g_free (summary);
+	    summary = gweather_info_get_sky (iter->data);
+	}
+	temp = gweather_info_get_temp_summary (iter->data);
+
+	g_string_append_printf (buffer, " * %s: %s, %s", date, summary, temp);
+
+	g_free (date);
+	g_free (summary);
+	g_free (temp);
+    }
+
+    return g_string_free (buffer, FALSE);
 }
